"""
Python module generated from Java source file com.google.common.collect.AbstractMapBasedMultiset

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.collect import *
from com.google.common.primitives import Ints
from com.google.errorprone.annotations import CanIgnoreReturnValue
from java.io import InvalidObjectException
from java.io import ObjectStreamException
from java.io import Serializable
from java.util import ConcurrentModificationException
from java.util import Iterator
from java.util.function import ObjIntConsumer
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class AbstractMapBasedMultiset(AbstractMultiset, Serializable):
    """
    Basic implementation of `Multiset<E>` backed by an instance of `Map<E, Count>`.
    
    For serialization to work, the subclass must specify explicit `readObject` and `writeObject` methods.

    Author(s)
    - Kevin Bourrillion
    """

    def entrySet(self) -> set["Multiset.Entry"["E"]]:
        """
        
        
        Invoking Multiset.Entry.getCount on an entry in the returned set always returns the
        current count of that element in the multiset, as opposed to the count at the time the entry
        was retrieved.
        """
        ...


    def forEachEntry(self, action: "ObjIntConsumer"["E"]) -> None:
        ...


    def clear(self) -> None:
        ...


    def size(self) -> int:
        ...


    def iterator(self) -> Iterator["E"]:
        ...


    def count(self, element: "Object") -> int:
        ...


    def add(self, element: "E", occurrences: int) -> int:
        """
        Raises
        - IllegalArgumentException: if the call would result in more than Integer.MAX_VALUE occurrences of `element` in this multiset.
        """
        ...


    def remove(self, element: "Object", occurrences: int) -> int:
        ...


    def setCount(self, element: "E", count: int) -> int:
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.inspector.TagInspector

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.yaml.snakeyaml.inspector import *
from org.yaml.snakeyaml.nodes import Tag
from typing import Any, Callable, Iterable, Tuple


class TagInspector:
    """
    Check if the global tags are allowed (the local tags are always allowed). It should control the
    classes to create to prevent possible remote code invocation when the data comes from untrusted
    source. The standard tags are always allowed (https://yaml.org/type/index.html)
    """

    def isGlobalTagAllowed(self, tag: "Tag") -> bool:
        """
        Check

        Arguments
        - tag: - the global tag to check

        Returns
        - True when the custom global tag is allowed to create a custom Java instance
        """
        ...



"""
Python module generated from Java source file org.bukkit.scheduler.BukkitScheduler

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util.concurrent import Callable
from java.util.concurrent import Future
from java.util.function import Consumer
from org.bukkit.plugin import Plugin
from org.bukkit.scheduler import *
from typing import Any, Callable, Iterable, Tuple


class BukkitScheduler:

    def scheduleSyncDelayedTask(self, plugin: "Plugin", task: "Runnable", delay: int) -> int:
        """
        Schedules a once off task to occur after a delay.
        
        This task will be executed by the main server thread.

        Arguments
        - plugin: Plugin that owns the task
        - task: Task to be executed
        - delay: Delay in server ticks before executing task

        Returns
        - Task id number (-1 if scheduling failed)
        """
        ...


    def scheduleSyncDelayedTask(self, plugin: "Plugin", task: "BukkitRunnable", delay: int) -> int:
        """
        Arguments
        - plugin: Plugin that owns the task
        - task: Task to be executed
        - delay: Delay in server ticks before executing task

        Returns
        - Task id number (-1 if scheduling failed)

        Deprecated
        - Use BukkitRunnable.runTaskLater(Plugin, long)
        """
        ...


    def scheduleSyncDelayedTask(self, plugin: "Plugin", task: "Runnable") -> int:
        """
        Schedules a once off task to occur as soon as possible.
        
        This task will be executed by the main server thread.

        Arguments
        - plugin: Plugin that owns the task
        - task: Task to be executed

        Returns
        - Task id number (-1 if scheduling failed)
        """
        ...


    def scheduleSyncDelayedTask(self, plugin: "Plugin", task: "BukkitRunnable") -> int:
        """
        Arguments
        - plugin: Plugin that owns the task
        - task: Task to be executed

        Returns
        - Task id number (-1 if scheduling failed)

        Deprecated
        - Use BukkitRunnable.runTask(Plugin)
        """
        ...


    def scheduleSyncRepeatingTask(self, plugin: "Plugin", task: "Runnable", delay: int, period: int) -> int:
        """
        Schedules a repeating task.
        
        This task will be executed by the main server thread.

        Arguments
        - plugin: Plugin that owns the task
        - task: Task to be executed
        - delay: Delay in server ticks before executing first repeat
        - period: Period in server ticks of the task

        Returns
        - Task id number (-1 if scheduling failed)
        """
        ...


    def scheduleSyncRepeatingTask(self, plugin: "Plugin", task: "BukkitRunnable", delay: int, period: int) -> int:
        """
        Arguments
        - plugin: Plugin that owns the task
        - task: Task to be executed
        - delay: Delay in server ticks before executing first repeat
        - period: Period in server ticks of the task

        Returns
        - Task id number (-1 if scheduling failed)

        Deprecated
        - Use BukkitRunnable.runTaskTimer(Plugin, long, long)
        """
        ...


    def scheduleAsyncDelayedTask(self, plugin: "Plugin", task: "Runnable", delay: int) -> int:
        """
        **Asynchronous tasks should never access any API in Bukkit.** **Great care
        should be taken to assure the thread-safety of asynchronous tasks.**
        
        Schedules a once off task to occur after a delay. This task will be
        executed by a thread managed by the scheduler.

        Arguments
        - plugin: Plugin that owns the task
        - task: Task to be executed
        - delay: Delay in server ticks before executing task

        Returns
        - Task id number (-1 if scheduling failed)

        Deprecated
        - This name is misleading, as it does not schedule "a sync"
            task, but rather, "an async" task
        """
        ...


    def scheduleAsyncDelayedTask(self, plugin: "Plugin", task: "Runnable") -> int:
        """
        **Asynchronous tasks should never access any API in Bukkit.** **Great care
        should be taken to assure the thread-safety of asynchronous tasks.**
        
        Schedules a once off task to occur as soon as possible. This task will
        be executed by a thread managed by the scheduler.

        Arguments
        - plugin: Plugin that owns the task
        - task: Task to be executed

        Returns
        - Task id number (-1 if scheduling failed)

        Deprecated
        - This name is misleading, as it does not schedule "a sync"
            task, but rather, "an async" task
        """
        ...


    def scheduleAsyncRepeatingTask(self, plugin: "Plugin", task: "Runnable", delay: int, period: int) -> int:
        """
        **Asynchronous tasks should never access any API in Bukkit.** **Great care
        should be taken to assure the thread-safety of asynchronous tasks.**
        
        Schedules a repeating task. This task will be executed by a thread
        managed by the scheduler.

        Arguments
        - plugin: Plugin that owns the task
        - task: Task to be executed
        - delay: Delay in server ticks before executing first repeat
        - period: Period in server ticks of the task

        Returns
        - Task id number (-1 if scheduling failed)

        Deprecated
        - This name is misleading, as it does not schedule "a sync"
            task, but rather, "an async" task
        """
        ...


    def callSyncMethod(self, plugin: "Plugin", task: "Callable"["T"]) -> "Future"["T"]:
        """
        Calls a method on the main thread and returns a Future object. This
        task will be executed by the main server thread.
        
        - Note: The Future.get() methods must NOT be called from the main
            thread.
        - Note2: There is at least an average of 10ms latency until the
            isDone() method returns True.
        
        
        Type `<T>`: The callable's return type

        Arguments
        - plugin: Plugin that owns the task
        - task: Task to be executed

        Returns
        - Future Future object related to the task
        """
        ...


    def cancelTask(self, taskId: int) -> None:
        """
        Removes task from scheduler.

        Arguments
        - taskId: Id number of task to be removed
        """
        ...


    def cancelTasks(self, plugin: "Plugin") -> None:
        """
        Removes all tasks associated with a particular plugin from the
        scheduler.

        Arguments
        - plugin: Owner of tasks to be removed
        """
        ...


    def isCurrentlyRunning(self, taskId: int) -> bool:
        """
        Check if the task currently running.
        
        A repeating task might not be running currently, but will be running in
        the future. A task that has finished, and does not repeat, will not be
        running ever again.
        
        Explicitly, a task is running if there exists a thread for it, and that
        thread is alive.

        Arguments
        - taskId: The task to check.

        Returns
        - If the task is currently running.
        """
        ...


    def isQueued(self, taskId: int) -> bool:
        """
        Check if the task queued to be run later.
        
        If a repeating task is currently running, it might not be queued now
        but could be in the future. A task that is not queued, and not running,
        will not be queued again.

        Arguments
        - taskId: The task to check.

        Returns
        - If the task is queued to be run.
        """
        ...


    def getActiveWorkers(self) -> list["BukkitWorker"]:
        """
        Returns a list of all active workers.
        
        This list contains asynch tasks that are being executed by separate
        threads.

        Returns
        - Active workers
        """
        ...


    def getPendingTasks(self) -> list["BukkitTask"]:
        """
        Returns a list of all pending tasks. The ordering of the tasks is not
        related to their order of execution.

        Returns
        - Active workers
        """
        ...


    def runTask(self, plugin: "Plugin", task: "Runnable") -> "BukkitTask":
        """
        Returns a task that will run on the next server tick.

        Arguments
        - plugin: the reference to the plugin scheduling task
        - task: the task to be run

        Returns
        - a BukkitTask that contains the id number

        Raises
        - IllegalArgumentException: if plugin is null
        - IllegalArgumentException: if task is null
        """
        ...


    def runTask(self, plugin: "Plugin", task: "Consumer"["BukkitTask"]) -> None:
        """
        Returns a task that will run on the next server tick.

        Arguments
        - plugin: the reference to the plugin scheduling task
        - task: the task to be run

        Raises
        - IllegalArgumentException: if plugin is null
        - IllegalArgumentException: if task is null
        """
        ...


    def runTask(self, plugin: "Plugin", task: "BukkitRunnable") -> "BukkitTask":
        """
        Arguments
        - plugin: the reference to the plugin scheduling task
        - task: the task to be run

        Returns
        - a BukkitTask that contains the id number

        Raises
        - IllegalArgumentException: if plugin is null
        - IllegalArgumentException: if task is null

        Deprecated
        - Use BukkitRunnable.runTask(Plugin)
        """
        ...


    def runTaskAsynchronously(self, plugin: "Plugin", task: "Runnable") -> "BukkitTask":
        """
        **Asynchronous tasks should never access any API in Bukkit.** **Great care
        should be taken to assure the thread-safety of asynchronous tasks.**
        
        Returns a task that will run asynchronously.

        Arguments
        - plugin: the reference to the plugin scheduling task
        - task: the task to be run

        Returns
        - a BukkitTask that contains the id number

        Raises
        - IllegalArgumentException: if plugin is null
        - IllegalArgumentException: if task is null
        """
        ...


    def runTaskAsynchronously(self, plugin: "Plugin", task: "Consumer"["BukkitTask"]) -> None:
        """
        **Asynchronous tasks should never access any API in Bukkit.** **Great care
        should be taken to assure the thread-safety of asynchronous tasks.**
        
        Returns a task that will run asynchronously.

        Arguments
        - plugin: the reference to the plugin scheduling task
        - task: the task to be run

        Raises
        - IllegalArgumentException: if plugin is null
        - IllegalArgumentException: if task is null
        """
        ...


    def runTaskAsynchronously(self, plugin: "Plugin", task: "BukkitRunnable") -> "BukkitTask":
        """
        Arguments
        - plugin: the reference to the plugin scheduling task
        - task: the task to be run

        Returns
        - a BukkitTask that contains the id number

        Raises
        - IllegalArgumentException: if plugin is null
        - IllegalArgumentException: if task is null

        Deprecated
        - Use BukkitRunnable.runTaskAsynchronously(Plugin)
        """
        ...


    def runTaskLater(self, plugin: "Plugin", task: "Runnable", delay: int) -> "BukkitTask":
        """
        Returns a task that will run after the specified number of server
        ticks.

        Arguments
        - plugin: the reference to the plugin scheduling task
        - task: the task to be run
        - delay: the ticks to wait before running the task

        Returns
        - a BukkitTask that contains the id number

        Raises
        - IllegalArgumentException: if plugin is null
        - IllegalArgumentException: if task is null
        """
        ...


    def runTaskLater(self, plugin: "Plugin", task: "Consumer"["BukkitTask"], delay: int) -> None:
        """
        Returns a task that will run after the specified number of server
        ticks.

        Arguments
        - plugin: the reference to the plugin scheduling task
        - task: the task to be run
        - delay: the ticks to wait before running the task

        Raises
        - IllegalArgumentException: if plugin is null
        - IllegalArgumentException: if task is null
        """
        ...


    def runTaskLater(self, plugin: "Plugin", task: "BukkitRunnable", delay: int) -> "BukkitTask":
        """
        Arguments
        - plugin: the reference to the plugin scheduling task
        - task: the task to be run
        - delay: the ticks to wait before running the task

        Returns
        - a BukkitTask that contains the id number

        Raises
        - IllegalArgumentException: if plugin is null
        - IllegalArgumentException: if task is null

        Deprecated
        - Use BukkitRunnable.runTaskLater(Plugin, long)
        """
        ...


    def runTaskLaterAsynchronously(self, plugin: "Plugin", task: "Runnable", delay: int) -> "BukkitTask":
        """
        **Asynchronous tasks should never access any API in Bukkit.** **Great care
        should be taken to assure the thread-safety of asynchronous tasks.**
        
        Returns a task that will run asynchronously after the specified number
        of server ticks.

        Arguments
        - plugin: the reference to the plugin scheduling task
        - task: the task to be run
        - delay: the ticks to wait before running the task

        Returns
        - a BukkitTask that contains the id number

        Raises
        - IllegalArgumentException: if plugin is null
        - IllegalArgumentException: if task is null
        """
        ...


    def runTaskLaterAsynchronously(self, plugin: "Plugin", task: "Consumer"["BukkitTask"], delay: int) -> None:
        """
        **Asynchronous tasks should never access any API in Bukkit.** **Great care
        should be taken to assure the thread-safety of asynchronous tasks.**
        
        Returns a task that will run asynchronously after the specified number
        of server ticks.

        Arguments
        - plugin: the reference to the plugin scheduling task
        - task: the task to be run
        - delay: the ticks to wait before running the task

        Raises
        - IllegalArgumentException: if plugin is null
        - IllegalArgumentException: if task is null
        """
        ...


    def runTaskLaterAsynchronously(self, plugin: "Plugin", task: "BukkitRunnable", delay: int) -> "BukkitTask":
        """
        Arguments
        - plugin: the reference to the plugin scheduling task
        - task: the task to be run
        - delay: the ticks to wait before running the task

        Returns
        - a BukkitTask that contains the id number

        Raises
        - IllegalArgumentException: if plugin is null
        - IllegalArgumentException: if task is null

        Deprecated
        - Use BukkitRunnable.runTaskLaterAsynchronously(Plugin, long)
        """
        ...


    def runTaskTimer(self, plugin: "Plugin", task: "Runnable", delay: int, period: int) -> "BukkitTask":
        """
        Returns a task that will repeatedly run until cancelled, starting after
        the specified number of server ticks.

        Arguments
        - plugin: the reference to the plugin scheduling task
        - task: the task to be run
        - delay: the ticks to wait before running the task
        - period: the ticks to wait between runs

        Returns
        - a BukkitTask that contains the id number

        Raises
        - IllegalArgumentException: if plugin is null
        - IllegalArgumentException: if task is null
        """
        ...


    def runTaskTimer(self, plugin: "Plugin", task: "Consumer"["BukkitTask"], delay: int, period: int) -> None:
        """
        Returns a task that will repeatedly run until cancelled, starting after
        the specified number of server ticks.

        Arguments
        - plugin: the reference to the plugin scheduling task
        - task: the task to be run
        - delay: the ticks to wait before running the task
        - period: the ticks to wait between runs

        Raises
        - IllegalArgumentException: if plugin is null
        - IllegalArgumentException: if task is null
        """
        ...


    def runTaskTimer(self, plugin: "Plugin", task: "BukkitRunnable", delay: int, period: int) -> "BukkitTask":
        """
        Arguments
        - plugin: the reference to the plugin scheduling task
        - task: the task to be run
        - delay: the ticks to wait before running the task
        - period: the ticks to wait between runs

        Returns
        - a BukkitTask that contains the id number

        Raises
        - IllegalArgumentException: if plugin is null
        - IllegalArgumentException: if task is null

        Deprecated
        - Use BukkitRunnable.runTaskTimer(Plugin, long, long)
        """
        ...


    def runTaskTimerAsynchronously(self, plugin: "Plugin", task: "Runnable", delay: int, period: int) -> "BukkitTask":
        """
        **Asynchronous tasks should never access any API in Bukkit.** **Great care
        should be taken to assure the thread-safety of asynchronous tasks.**
        
        Returns a task that will repeatedly run asynchronously until cancelled,
        starting after the specified number of server ticks.

        Arguments
        - plugin: the reference to the plugin scheduling task
        - task: the task to be run
        - delay: the ticks to wait before running the task for the first
            time
        - period: the ticks to wait between runs

        Returns
        - a BukkitTask that contains the id number

        Raises
        - IllegalArgumentException: if plugin is null
        - IllegalArgumentException: if task is null
        """
        ...


    def runTaskTimerAsynchronously(self, plugin: "Plugin", task: "Consumer"["BukkitTask"], delay: int, period: int) -> None:
        """
        **Asynchronous tasks should never access any API in Bukkit.** **Great care
        should be taken to assure the thread-safety of asynchronous tasks.**
        
        Returns a task that will repeatedly run asynchronously until cancelled,
        starting after the specified number of server ticks.

        Arguments
        - plugin: the reference to the plugin scheduling task
        - task: the task to be run
        - delay: the ticks to wait before running the task for the first
            time
        - period: the ticks to wait between runs

        Raises
        - IllegalArgumentException: if plugin is null
        - IllegalArgumentException: if task is null
        """
        ...


    def runTaskTimerAsynchronously(self, plugin: "Plugin", task: "BukkitRunnable", delay: int, period: int) -> "BukkitTask":
        """
        Arguments
        - plugin: the reference to the plugin scheduling task
        - task: the task to be run
        - delay: the ticks to wait before running the task for the first
            time
        - period: the ticks to wait between runs

        Returns
        - a BukkitTask that contains the id number

        Raises
        - IllegalArgumentException: if plugin is null
        - IllegalArgumentException: if task is null

        Deprecated
        - Use BukkitRunnable.runTaskTimerAsynchronously(Plugin, long, long)
        """
        ...



"""
Python module generated from Java source file java.util.SortedMap

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import *
from typing import Any, Callable, Iterable, Tuple


class SortedMap(Map):

    def comparator(self) -> "Comparator"["K"]:
        """
        Returns the comparator used to order the keys in this map, or
        `null` if this map uses the Comparable
        natural ordering of its keys.

        Returns
        - the comparator used to order the keys in this map,
                or `null` if this map uses the natural ordering
                of its keys
        """
        ...


    def subMap(self, fromKey: "K", toKey: "K") -> "SortedMap"["K", "V"]:
        """
        Returns a view of the portion of this map whose keys range from
        `fromKey`, inclusive, to `toKey`, exclusive.  (If
        `fromKey` and `toKey` are equal, the returned map
        is empty.)  The returned map is backed by this map, so changes
        in the returned map are reflected in this map, and vice-versa.
        The returned map supports all optional map operations that this
        map supports.
        
        The returned map will throw an `IllegalArgumentException`
        on an attempt to insert a key outside its range.

        Arguments
        - fromKey: low endpoint (inclusive) of the keys in the returned map
        - toKey: high endpoint (exclusive) of the keys in the returned map

        Returns
        - a view of the portion of this map whose keys range from
                `fromKey`, inclusive, to `toKey`, exclusive

        Raises
        - ClassCastException: if `fromKey` and `toKey`
                cannot be compared to one another using this map's comparator
                (or, if the map has no comparator, using natural ordering).
                Implementations may, but are not required to, throw this
                exception if `fromKey` or `toKey`
                cannot be compared to keys currently in the map.
        - NullPointerException: if `fromKey` or `toKey`
                is null and this map does not permit null keys
        - IllegalArgumentException: if `fromKey` is greater than
                `toKey`; or if this map itself has a restricted
                range, and `fromKey` or `toKey` lies
                outside the bounds of the range
        """
        ...


    def headMap(self, toKey: "K") -> "SortedMap"["K", "V"]:
        """
        Returns a view of the portion of this map whose keys are
        strictly less than `toKey`.  The returned map is backed
        by this map, so changes in the returned map are reflected in
        this map, and vice-versa.  The returned map supports all
        optional map operations that this map supports.
        
        The returned map will throw an `IllegalArgumentException`
        on an attempt to insert a key outside its range.

        Arguments
        - toKey: high endpoint (exclusive) of the keys in the returned map

        Returns
        - a view of the portion of this map whose keys are strictly
                less than `toKey`

        Raises
        - ClassCastException: if `toKey` is not compatible
                with this map's comparator (or, if the map has no comparator,
                if `toKey` does not implement Comparable).
                Implementations may, but are not required to, throw this
                exception if `toKey` cannot be compared to keys
                currently in the map.
        - NullPointerException: if `toKey` is null and
                this map does not permit null keys
        - IllegalArgumentException: if this map itself has a
                restricted range, and `toKey` lies outside the
                bounds of the range
        """
        ...


    def tailMap(self, fromKey: "K") -> "SortedMap"["K", "V"]:
        """
        Returns a view of the portion of this map whose keys are
        greater than or equal to `fromKey`.  The returned map is
        backed by this map, so changes in the returned map are
        reflected in this map, and vice-versa.  The returned map
        supports all optional map operations that this map supports.
        
        The returned map will throw an `IllegalArgumentException`
        on an attempt to insert a key outside its range.

        Arguments
        - fromKey: low endpoint (inclusive) of the keys in the returned map

        Returns
        - a view of the portion of this map whose keys are greater
                than or equal to `fromKey`

        Raises
        - ClassCastException: if `fromKey` is not compatible
                with this map's comparator (or, if the map has no comparator,
                if `fromKey` does not implement Comparable).
                Implementations may, but are not required to, throw this
                exception if `fromKey` cannot be compared to keys
                currently in the map.
        - NullPointerException: if `fromKey` is null and
                this map does not permit null keys
        - IllegalArgumentException: if this map itself has a
                restricted range, and `fromKey` lies outside the
                bounds of the range
        """
        ...


    def firstKey(self) -> "K":
        """
        Returns the first (lowest) key currently in this map.

        Returns
        - the first (lowest) key currently in this map

        Raises
        - NoSuchElementException: if this map is empty
        """
        ...


    def lastKey(self) -> "K":
        """
        Returns the last (highest) key currently in this map.

        Returns
        - the last (highest) key currently in this map

        Raises
        - NoSuchElementException: if this map is empty
        """
        ...


    def keySet(self) -> set["K"]:
        """
        Returns a Set view of the keys contained in this map.
        The set's iterator returns the keys in ascending order.
        The set is backed by the map, so changes to the map are
        reflected in the set, and vice-versa.  If the map is modified
        while an iteration over the set is in progress (except through
        the iterator's own `remove` operation), the results of
        the iteration are undefined.  The set supports element removal,
        which removes the corresponding mapping from the map, via the
        `Iterator.remove`, `Set.remove`,
        `removeAll`, `retainAll`, and `clear`
        operations.  It does not support the `add` or `addAll`
        operations.

        Returns
        - a set view of the keys contained in this map, sorted in
                ascending order
        """
        ...


    def values(self) -> Iterable["V"]:
        """
        Returns a Collection view of the values contained in this map.
        The collection's iterator returns the values in ascending order
        of the corresponding keys.
        The collection is backed by the map, so changes to the map are
        reflected in the collection, and vice-versa.  If the map is
        modified while an iteration over the collection is in progress
        (except through the iterator's own `remove` operation),
        the results of the iteration are undefined.  The collection
        supports element removal, which removes the corresponding
        mapping from the map, via the `Iterator.remove`,
        `Collection.remove`, `removeAll`,
        `retainAll` and `clear` operations.  It does not
        support the `add` or `addAll` operations.

        Returns
        - a collection view of the values contained in this map,
                sorted in ascending key order
        """
        ...


    def entrySet(self) -> set["Map.Entry"["K", "V"]]:
        """
        Returns a Set view of the mappings contained in this map.
        The set's iterator returns the entries in ascending key order.
        The set is backed by the map, so changes to the map are
        reflected in the set, and vice-versa.  If the map is modified
        while an iteration over the set is in progress (except through
        the iterator's own `remove` operation, or through the
        `setValue` operation on a map entry returned by the
        iterator) the results of the iteration are undefined.  The set
        supports element removal, which removes the corresponding
        mapping from the map, via the `Iterator.remove`,
        `Set.remove`, `removeAll`, `retainAll` and
        `clear` operations.  It does not support the
        `add` or `addAll` operations.

        Returns
        - a set view of the mappings contained in this map,
                sorted in ascending key order
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.entity.ItemDespawnEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Location
from org.bukkit.entity import Item
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.entity import *
from typing import Any, Callable, Iterable, Tuple


class ItemDespawnEvent(EntityEvent, Cancellable):
    """
    This event is called when a org.bukkit.entity.Item is removed from
    the world because it has existed for 5 minutes.
    
    Cancelling the event results in the item being allowed to exist for 5 more
    minutes. This behavior is not guaranteed and may change in future versions.
    """

    def __init__(self, despawnee: "Item", loc: "Location"):
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getEntity(self) -> "Item":
        ...


    def getLocation(self) -> "Location":
        """
        Gets the location at which the item is despawning.

        Returns
        - The location at which the item is despawning
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.block.data.type.Scaffolding

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block.data import Waterlogged
from org.bukkit.block.data.type import *
from typing import Any, Callable, Iterable, Tuple


class Scaffolding(Waterlogged):
    """
    'bottom' indicates whether the scaffolding is floating or not.
    
    'distance' indicates the distance from a scaffolding block placed above a
    'bottom' scaffold.
    
    When 'distance' reaches .getMaximumDistance() the block will drop.
    """

    def isBottom(self) -> bool:
        """
        Gets the value of the 'bottom' property.

        Returns
        - the 'bottom' value
        """
        ...


    def setBottom(self, bottom: bool) -> None:
        """
        Sets the value of the 'bottom' property.

        Arguments
        - bottom: the new 'bottom' value
        """
        ...


    def getDistance(self) -> int:
        """
        Gets the value of the 'distance' property.

        Returns
        - the 'distance' value
        """
        ...


    def setDistance(self, distance: int) -> None:
        """
        Sets the value of the 'distance' property.

        Arguments
        - distance: the new 'distance' value
        """
        ...


    def getMaximumDistance(self) -> int:
        """
        Gets the maximum allowed value of the 'distance' property.

        Returns
        - the maximum 'distance' value
        """
        ...



"""
Python module generated from Java source file com.google.common.util.concurrent.AbstractIdleService

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.base import Supplier
from com.google.common.util.concurrent import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from com.google.j2objc.annotations import WeakOuter
from java.time import Duration
from java.util.concurrent import Executor
from java.util.concurrent import TimeUnit
from java.util.concurrent import TimeoutException
from typing import Any, Callable, Iterable, Tuple


class AbstractIdleService(Service):
    """
    Base class for services that do not need a thread while "running" but may need one during startup
    and shutdown. Subclasses can implement .startUp and .shutDown methods, each which
    run in an executor which by default uses a separate thread for each method.

    Author(s)
    - Chris Nokleberg

    Since
    - 1.0
    """

    def toString(self) -> str:
        ...


    def isRunning(self) -> bool:
        ...


    def state(self) -> "State":
        ...


    def addListener(self, listener: "Listener", executor: "Executor") -> None:
        """
        Since
        - 13.0
        """
        ...


    def failureCause(self) -> "Throwable":
        """
        Since
        - 14.0
        """
        ...


    def startAsync(self) -> "Service":
        """
        Since
        - 15.0
        """
        ...


    def stopAsync(self) -> "Service":
        """
        Since
        - 15.0
        """
        ...


    def awaitRunning(self) -> None:
        """
        Since
        - 15.0
        """
        ...


    def awaitRunning(self, timeout: "Duration") -> None:
        """
        Since
        - 28.0
        """
        ...


    def awaitRunning(self, timeout: int, unit: "TimeUnit") -> None:
        """
        Since
        - 15.0
        """
        ...


    def awaitTerminated(self) -> None:
        """
        Since
        - 15.0
        """
        ...


    def awaitTerminated(self, timeout: "Duration") -> None:
        """
        Since
        - 28.0
        """
        ...


    def awaitTerminated(self, timeout: int, unit: "TimeUnit") -> None:
        """
        Since
        - 15.0
        """
        ...



"""
Python module generated from Java source file org.bukkit.inventory.StonecuttingRecipe

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from java.util import Collections
from org.bukkit import Keyed
from org.bukkit import Material
from org.bukkit import NamespacedKey
from org.bukkit.inventory import *
from typing import Any, Callable, Iterable, Tuple


class StonecuttingRecipe(Recipe, Keyed):
    """
    Represents a Stonecutting recipe.
    """

    def __init__(self, key: "NamespacedKey", result: "ItemStack", source: "Material"):
        """
        Create a Stonecutting recipe to craft the specified ItemStack.

        Arguments
        - key: The unique recipe key
        - result: The item you want the recipe to create.
        - source: The input material.
        """
        ...


    def __init__(self, key: "NamespacedKey", result: "ItemStack", input: "RecipeChoice"):
        """
        Create a cooking recipe to craft the specified ItemStack.

        Arguments
        - key: The unique recipe key
        - result: The item you want the recipe to create.
        - input: The input choices.
        """
        ...


    def setInput(self, input: "Material") -> "StonecuttingRecipe":
        """
        Sets the input of this cooking recipe.

        Arguments
        - input: The input material.

        Returns
        - The changed recipe, so you can chain calls.
        """
        ...


    def getInput(self) -> "ItemStack":
        """
        Get the input material.

        Returns
        - The input material.
        """
        ...


    def setInputChoice(self, input: "RecipeChoice") -> "StonecuttingRecipe":
        """
        Sets the input of this cooking recipe.

        Arguments
        - input: The input choice.

        Returns
        - The changed recipe, so you can chain calls.
        """
        ...


    def getInputChoice(self) -> "RecipeChoice":
        """
        Get the input choice.

        Returns
        - The input choice.
        """
        ...


    def getResult(self) -> "ItemStack":
        """
        Get the result of this recipe.

        Returns
        - The resulting stack.
        """
        ...


    def getKey(self) -> "NamespacedKey":
        ...


    def getGroup(self) -> str:
        """
        Get the group of this recipe. Recipes with the same group may be grouped
        together when displayed in the client.

        Returns
        - recipe group. An empty string denotes no group. May not be null.
        """
        ...


    def setGroup(self, group: str) -> None:
        """
        Set the group of this recipe. Recipes with the same group may be grouped
        together when displayed in the client.

        Arguments
        - group: recipe group. An empty string denotes no group. May not be
        null.
        """
        ...



from .TextSerializer import TextSerializer
from .Text import Text
from .ItemSerializer import ItemSerializer
from .Item import Item
from .EntitySerializer import EntitySerializer
from .Entity import Entity
from .Content import Content


"""
Python module generated from Java source file org.bukkit.inventory.ShapelessRecipe

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from java.util import Collections
from java.util import Iterator
from org.bukkit import Material
from org.bukkit import NamespacedKey
from org.bukkit.inventory import *
from org.bukkit.material import MaterialData
from typing import Any, Callable, Iterable, Tuple


class ShapelessRecipe(CraftingRecipe):
    """
    Represents a shapeless recipe, where the arrangement of the ingredients on
    the crafting grid does not matter.
    """

    def __init__(self, result: "ItemStack"):
        ...


    def __init__(self, key: "NamespacedKey", result: "ItemStack"):
        """
        Create a shapeless recipe to craft the specified ItemStack. The
        constructor merely determines the result and type; to set the actual
        recipe, you'll need to call the appropriate methods.

        Arguments
        - key: the unique recipe key
        - result: The item you want the recipe to create.

        Raises
        - IllegalArgumentException: if the `result` is an empty item (AIR)

        See
        - ShapelessRecipe.addIngredient(int,Material,int)
        """
        ...


    def addIngredient(self, ingredient: "MaterialData") -> "ShapelessRecipe":
        """
        Adds the specified ingredient.

        Arguments
        - ingredient: The ingredient to add.

        Returns
        - The changed recipe, so you can chain calls.
        """
        ...


    def addIngredient(self, ingredient: "Material") -> "ShapelessRecipe":
        """
        Adds the specified ingredient.

        Arguments
        - ingredient: The ingredient to add.

        Returns
        - The changed recipe, so you can chain calls.
        """
        ...


    def addIngredient(self, ingredient: "Material", rawdata: int) -> "ShapelessRecipe":
        """
        Adds the specified ingredient.

        Arguments
        - ingredient: The ingredient to add.
        - rawdata: The data value, or -1 to allow any data value.

        Returns
        - The changed recipe, so you can chain calls.

        Deprecated
        - Magic value
        """
        ...


    def addIngredient(self, count: int, ingredient: "MaterialData") -> "ShapelessRecipe":
        """
        Adds multiples of the specified ingredient.

        Arguments
        - count: How many to add (can't be more than 9!)
        - ingredient: The ingredient to add.

        Returns
        - The changed recipe, so you can chain calls.
        """
        ...


    def addIngredient(self, count: int, ingredient: "Material") -> "ShapelessRecipe":
        """
        Adds multiples of the specified ingredient.

        Arguments
        - count: How many to add (can't be more than 9!)
        - ingredient: The ingredient to add.

        Returns
        - The changed recipe, so you can chain calls.
        """
        ...


    def addIngredient(self, count: int, ingredient: "Material", rawdata: int) -> "ShapelessRecipe":
        """
        Adds multiples of the specified ingredient.

        Arguments
        - count: How many to add (can't be more than 9!)
        - ingredient: The ingredient to add.
        - rawdata: The data value, or -1 to allow any data value.

        Returns
        - The changed recipe, so you can chain calls.

        Deprecated
        - Magic value
        """
        ...


    def addIngredient(self, ingredient: "RecipeChoice") -> "ShapelessRecipe":
        ...


    def removeIngredient(self, ingredient: "RecipeChoice") -> "ShapelessRecipe":
        """
        Removes an ingredient from the list.

        Arguments
        - ingredient: The ingredient to remove

        Returns
        - The changed recipe.
        """
        ...


    def removeIngredient(self, ingredient: "Material") -> "ShapelessRecipe":
        """
        Removes an ingredient from the list. If the ingredient occurs multiple
        times, only one instance of it is removed. Only removes exact matches,
        with a data value of 0.

        Arguments
        - ingredient: The ingredient to remove

        Returns
        - The changed recipe.
        """
        ...


    def removeIngredient(self, ingredient: "MaterialData") -> "ShapelessRecipe":
        """
        Removes an ingredient from the list. If the ingredient occurs multiple
        times, only one instance of it is removed. If the data value is -1,
        only ingredients with a -1 data value will be removed.

        Arguments
        - ingredient: The ingredient to remove

        Returns
        - The changed recipe.
        """
        ...


    def removeIngredient(self, count: int, ingredient: "Material") -> "ShapelessRecipe":
        """
        Removes multiple instances of an ingredient from the list. If there are
        less instances then specified, all will be removed. Only removes exact
        matches, with a data value of 0.

        Arguments
        - count: The number of copies to remove.
        - ingredient: The ingredient to remove

        Returns
        - The changed recipe.
        """
        ...


    def removeIngredient(self, count: int, ingredient: "MaterialData") -> "ShapelessRecipe":
        """
        Removes multiple instances of an ingredient from the list. If there are
        less instances then specified, all will be removed. If the data value
        is -1, only ingredients with a -1 data value will be removed.

        Arguments
        - count: The number of copies to remove.
        - ingredient: The ingredient to remove.

        Returns
        - The changed recipe.
        """
        ...


    def removeIngredient(self, ingredient: "Material", rawdata: int) -> "ShapelessRecipe":
        """
        Removes an ingredient from the list. If the ingredient occurs multiple
        times, only one instance of it is removed. If the data value is -1,
        only ingredients with a -1 data value will be removed.

        Arguments
        - ingredient: The ingredient to remove
        - rawdata: The data value;

        Returns
        - The changed recipe.

        Deprecated
        - Magic value
        """
        ...


    def removeIngredient(self, count: int, ingredient: "Material", rawdata: int) -> "ShapelessRecipe":
        """
        Removes multiple instances of an ingredient from the list. If there are
        less instances then specified, all will be removed. If the data value
        is -1, only ingredients with a -1 data value will be removed.

        Arguments
        - count: The number of copies to remove.
        - ingredient: The ingredient to remove.
        - rawdata: The data value.

        Returns
        - The changed recipe.

        Deprecated
        - Magic value
        """
        ...


    def getIngredientList(self) -> list["ItemStack"]:
        """
        Get the list of ingredients used for this recipe.

        Returns
        - The input list
        """
        ...


    def getChoiceList(self) -> list["RecipeChoice"]:
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.introspector.PropertySubstitute

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.lang.reflect import Array
from java.lang.reflect import Field
from java.lang.reflect import Method
from java.lang.reflect import Modifier
from java.util import Arrays
from org.yaml.snakeyaml.error import YAMLException
from org.yaml.snakeyaml.internal import Logger
from org.yaml.snakeyaml.internal.Logger import Level
from org.yaml.snakeyaml.introspector import *
from typing import Any, Callable, Iterable, Tuple


class PropertySubstitute(Property):

    def __init__(self, name: str, type: type[Any], readMethod: str, writeMethod: str, *params: Tuple[type[Any], ...]):
        ...


    def __init__(self, name: str, type: type[Any], *params: Tuple[type[Any], ...]):
        ...


    def getActualTypeArguments(self) -> list[type[Any]]:
        ...


    def setActualTypeArguments(self, *args: Tuple[type[Any], ...]) -> None:
        ...


    def set(self, object: "Object", value: "Object") -> None:
        ...


    def get(self, object: "Object") -> "Object":
        ...


    def getAnnotations(self) -> list["Annotation"]:
        ...


    def getAnnotation(self, annotationType: type["A"]) -> "A":
        ...


    def setTargetType(self, targetType: type[Any]) -> None:
        ...


    def getName(self) -> str:
        ...


    def getType(self) -> type[Any]:
        ...


    def isReadable(self) -> bool:
        ...


    def isWritable(self) -> bool:
        ...


    def setDelegate(self, delegate: "Property") -> None:
        ...



"""
Python module generated from Java source file org.bukkit.block.Structure

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import *
from org.bukkit.block.structure import Mirror
from org.bukkit.block.structure import StructureRotation
from org.bukkit.block.structure import UsageMode
from org.bukkit.entity import LivingEntity
from org.bukkit.util import BlockVector
from typing import Any, Callable, Iterable, Tuple


class Structure(TileState):
    """
    Represents a structure block that can save and load blocks from a file. They
    can only be used by OPs, and are not obtainable in survival.
    """

    def getStructureName(self) -> str:
        """
        The name of this structure.

        Returns
        - structure name
        """
        ...


    def setStructureName(self, name: str) -> None:
        """
        Set the name of this structure. This is case-sensitive. The name of the
        structure in the UsageMode.SAVE structure block MUST match the
        name within the UsageMode.CORNER block or the size calculation
        will fail.

        Arguments
        - name: the case-sensitive name of this structure
        """
        ...


    def getAuthor(self) -> str:
        """
        Get the name of who created this structure.

        Returns
        - the name of whoever created this structure.
        """
        ...


    def setAuthor(self, author: str) -> None:
        """
        Set the name of whoever created this structure.

        Arguments
        - author: whoever created this structure (not empty)
        """
        ...


    def setAuthor(self, livingEntity: "LivingEntity") -> None:
        """
        Set the name of whoever created this structure using a
        LivingEntity.

        Arguments
        - livingEntity: the entity who created this structure
        """
        ...


    def getRelativePosition(self) -> "BlockVector":
        """
        The relative position of the structure outline based on the position of
        the structure block. Maximum allowed distance is 48 blocks in any
        direction.

        Returns
        - a Location which contains the relative distance this structure is
        from the structure block.
        """
        ...


    def setRelativePosition(self, vector: "BlockVector") -> None:
        """
        Set the relative position from the structure block. Maximum allowed
        distance is 48 blocks in any direction.

        Arguments
        - vector: the BlockVector containing the relative origin
        coordinates of this structure.
        """
        ...


    def getStructureSize(self) -> "BlockVector":
        """
        The distance to the opposite corner of this structure. The maximum
        structure size is 48x48x48. When a structure has successfully been
        calculated (i.e. it is within the maximum allowed distance) a white
        border surrounds the structure.

        Returns
        - a BlockVector which contains the total size of the
        structure.
        """
        ...


    def setStructureSize(self, vector: "BlockVector") -> None:
        """
        Set the maximum size of this structure from the origin point. Maximum
        allowed size is 48x48x48.

        Arguments
        - vector: the BlockVector containing the size of this
        structure, based off of the origin coordinates.
        """
        ...


    def setMirror(self, mirror: "Mirror") -> None:
        """
        Sets the mirroring of the structure.

        Arguments
        - mirror: the new mirroring method
        """
        ...


    def getMirror(self) -> "Mirror":
        """
        How this structure is mirrored.

        Returns
        - the current mirroring method
        """
        ...


    def setRotation(self, rotation: "StructureRotation") -> None:
        """
        Set how this structure is rotated.

        Arguments
        - rotation: the new rotation
        """
        ...


    def getRotation(self) -> "StructureRotation":
        """
        Get how this structure is rotated.

        Returns
        - the new rotation
        """
        ...


    def setUsageMode(self, mode: "UsageMode") -> None:
        """
        Set the UsageMode of this structure block.

        Arguments
        - mode: the new mode to set.
        """
        ...


    def getUsageMode(self) -> "UsageMode":
        """
        Get the UsageMode of this structure block.

        Returns
        - the mode this block is currently in.
        """
        ...


    def setIgnoreEntities(self, ignoreEntities: bool) -> None:
        """
        While in UsageMode.SAVE mode, this will ignore any entities when
        saving the structure.
        
        While in UsageMode.LOAD mode this will ignore any entities that
        were saved to file.

        Arguments
        - ignoreEntities: the flag to set
        """
        ...


    def isIgnoreEntities(self) -> bool:
        """
        Get if this structure block should ignore entities.

        Returns
        - True if the appropriate UsageMode should ignore entities.
        """
        ...


    def setShowAir(self, showAir: bool) -> None:
        """
        Set if the structure outline should show air blocks.

        Arguments
        - showAir: if the structure block should show air blocks
        """
        ...


    def isShowAir(self) -> bool:
        """
        Check if this structure block is currently showing all air blocks

        Returns
        - True if the structure block is showing all air blocks
        """
        ...


    def setBoundingBoxVisible(self, showBoundingBox: bool) -> None:
        """
        Set if this structure box should show the bounding box.

        Arguments
        - showBoundingBox: if the structure box should be shown
        """
        ...


    def isBoundingBoxVisible(self) -> bool:
        """
        Get if this structure block is currently showing the bounding box.

        Returns
        - True if the bounding box is shown
        """
        ...


    def setIntegrity(self, integrity: float) -> None:
        """
        Set the integrity of the structure. Integrity must be between 0.0 and 1.0
        Lower integrity values will result in more blocks being removed when
        loading a structure. Integrity and .getSeed() are used together
        to determine which blocks are randomly removed to mimic "decay."

        Arguments
        - integrity: the integrity of this structure
        """
        ...


    def getIntegrity(self) -> float:
        """
        Get the integrity of this structure.

        Returns
        - the integrity of this structure
        """
        ...


    def setSeed(self, seed: int) -> None:
        """
        The seed used to determine which blocks will be removed upon loading.
        .getIntegrity() and seed are used together to determine which
        blocks are randomly removed to mimic "decay."

        Arguments
        - seed: the seed used to determine how many blocks will be removed
        """
        ...


    def getSeed(self) -> int:
        """
        The seed used to determine how many blocks are removed upon loading of
        this structure.

        Returns
        - the seed used
        """
        ...


    def setMetadata(self, metadata: str) -> None:
        """
        Only applicable while in UsageMode.DATA. Metadata are specific
        functions that can be applied to the structure location. Consult the
        <a href="https://minecraft.wiki/w/Structure_Block#Data">Minecraft
        wiki</a> for more information.

        Arguments
        - metadata: the function to perform on the selected location
        """
        ...


    def getMetadata(self) -> str:
        """
        Get the metadata function this structure block will perform when
        activated. Consult the
        <a href="https://minecraft.wiki/w/Structure_Block#Data">Minecraft
        Wiki</a> for more information.

        Returns
        - the function that will be performed when this block is activated
        """
        ...



"""
Python module generated from Java source file com.google.common.util.concurrent.ForwardingCondition

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import J2ktIncompatible
from com.google.common.util.concurrent import *
from java.util import Date
from java.util.concurrent import TimeUnit
from java.util.concurrent.locks import Condition
from typing import Any, Callable, Iterable, Tuple


class ForwardingCondition(Condition):
    """
    Forwarding wrapper around a `Condition`.
    """

    def await(self) -> None:
        ...


    def await(self, time: int, unit: "TimeUnit") -> bool:
        ...


    def awaitUninterruptibly(self) -> None:
        ...


    def awaitNanos(self, nanosTimeout: int) -> int:
        ...


    def awaitUntil(self, deadline: "Date") -> bool:
        ...


    def signal(self) -> None:
        ...


    def signalAll(self) -> None:
        ...



"""
Python module generated from Java source file com.google.gson.ExclusionStrategy

Java source file obtained from artifact gson version 2.11.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import *
from typing import Any, Callable, Iterable, Tuple


class ExclusionStrategy:
    """
    A strategy (or policy) definition that is used to decide whether or not a field or class should
    be serialized or deserialized as part of the JSON output/input.
    
    The following are a few examples that shows how you can use this exclusion mechanism.
    
    <strong>Exclude fields and objects based on a particular class type:</strong>
    
    <pre class="code">
    private static class SpecificClassExclusionStrategy implements ExclusionStrategy {
      private final Class&lt;?&gt; excludedThisClass;
    
      public SpecificClassExclusionStrategy(Class&lt;?&gt; excludedThisClass) {
        this.excludedThisClass = excludedThisClass;
      }
    
      public boolean shouldSkipClass(Class&lt;?&gt; clazz) {
        return excludedThisClass.equals(clazz);
      }
    
      public boolean shouldSkipField(FieldAttributes f) {
        return excludedThisClass.equals(f.getDeclaredClass());
      }
    }
    ```
    
    <strong>Excludes fields and objects based on a particular annotation:</strong>
    
    <pre class="code">
    public &#64;interface FooAnnotation {
      // some implementation here
    }
    
    // Excludes any field (or class) that is tagged with an "&#64;FooAnnotation"
    private static class FooAnnotationExclusionStrategy implements ExclusionStrategy {
      public boolean shouldSkipClass(Class&lt;?&gt; clazz) {
        return clazz.getAnnotation(FooAnnotation.class) != null;
      }
    
      public boolean shouldSkipField(FieldAttributes f) {
        return f.getAnnotation(FooAnnotation.class) != null;
      }
    }
    ```
    
    Now if you want to configure `Gson` to use a user defined exclusion strategy, then the
    `GsonBuilder` is required. The following is an example of how you can use the `GsonBuilder` to configure Gson to use one of the above samples:
    
    <pre class="code">
    ExclusionStrategy excludeStrings = new UserDefinedExclusionStrategy(String.class);
    Gson gson = new GsonBuilder()
        .setExclusionStrategies(excludeStrings)
        .create();
    ```
    
    For certain model classes, you may only want to serialize a field, but exclude it for
    deserialization. To do that, you can write an `ExclusionStrategy` as per normal; however,
    you would register it with the GsonBuilder.addDeserializationExclusionStrategy(ExclusionStrategy) method. For example:
    
    <pre class="code">
    ExclusionStrategy excludeStrings = new UserDefinedExclusionStrategy(String.class);
    Gson gson = new GsonBuilder()
        .addDeserializationExclusionStrategy(excludeStrings)
        .create();
    ```

    Author(s)
    - Joel Leitch

    See
    - GsonBuilder.addSerializationExclusionStrategy(ExclusionStrategy)

    Since
    - 1.4
    """

    def shouldSkipField(self, f: "FieldAttributes") -> bool:
        """
        Decides if a field should be skipped during serialization or deserialization.

        Arguments
        - f: the field object that is under test

        Returns
        - True if the field should be ignored; otherwise False
        """
        ...


    def shouldSkipClass(self, clazz: type[Any]) -> bool:
        """
        Decides if a class should be serialized or deserialized

        Arguments
        - clazz: the class object that is under test

        Returns
        - True if the class should be ignored; otherwise False
        """
        ...



"""
Python module generated from Java source file org.bukkit.block.data.type.PointedDripstone

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.block import BlockFace
from org.bukkit.block.data import Waterlogged
from org.bukkit.block.data.type import *
from typing import Any, Callable, Iterable, Tuple


class PointedDripstone(Waterlogged):
    """
    'thickness' represents the dripstone thickness.
    
    'vertical_direction' represents the dripstone orientation.
    
    Some blocks may not be able to face in all directions, use
    .getVerticalDirections() to get all possible directions for this
    block.
    """

    def getVerticalDirection(self) -> "BlockFace":
        """
        Gets the value of the 'vertical_direction' property.

        Returns
        - the 'vertical_direction' value
        """
        ...


    def setVerticalDirection(self, direction: "BlockFace") -> None:
        """
        Sets the value of the 'vertical_direction' property.

        Arguments
        - direction: the new 'vertical_direction' value
        """
        ...


    def getVerticalDirections(self) -> set["BlockFace"]:
        """
        Gets the faces which are applicable to this block.

        Returns
        - the allowed 'vertical_direction' values
        """
        ...


    def getThickness(self) -> "Thickness":
        """
        Gets the value of the 'thickness' property.

        Returns
        - the 'thickness' value
        """
        ...


    def setThickness(self, thickness: "Thickness") -> None:
        """
        Sets the value of the 'thickness' property.

        Arguments
        - thickness: the new 'thickness' value
        """
        ...


    class Thickness(Enum):
        """
        Represents the thickness of the dripstone, corresponding to its position
        within a multi-block dripstone formation.
        """

        TIP_MERGE = 0
        """
        Extended tip.
        """
        TIP = 1
        """
        Just the tip.
        """
        FRUSTUM = 2
        """
        Top section.
        """
        MIDDLE = 3
        """
        Middle section.
        """
        BASE = 4
        """
        Base.
        """



"""
Python module generated from Java source file org.bukkit.block.Beehive

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Location
from org.bukkit.block import *
from org.bukkit.entity import Bee
from typing import Any, Callable, Iterable, Tuple


class Beehive(EntityBlockStorage):
    """
    Represents a captured state of a bee hive.
    """

    def getFlower(self) -> "Location":
        """
        Get the hive's flower location.

        Returns
        - flower location or null
        """
        ...


    def setFlower(self, location: "Location") -> None:
        """
        Set the hive's flower location.

        Arguments
        - location: or null
        """
        ...


    def isSedated(self) -> bool:
        """
        Check if the hive is sedated due to smoke from a nearby campfire.

        Returns
        - True if hive is sedated
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.CompactLinkedHashSet

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.collect import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from java.util import Arrays
from java.util import Collections
from java.util import Spliterator
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class CompactLinkedHashSet(CompactHashSet):
    """
    CompactLinkedHashSet is an implementation of a Set, which a predictable iteration order that
    matches the insertion order. All optional operations (adding and removing) are supported. All
    elements, including `null`, are permitted.
    
    `contains(x)`, `add(x)` and `remove(x)`, are all (expected and amortized)
    constant time operations. Expected in the hashtable sense (depends on the hash function doing a
    good job of distributing the elements to the buckets to a distribution not far from uniform), and
    amortized since some operations can trigger a hash table resize.
    
    This implementation consumes significantly less memory than `java.util.LinkedHashSet` or
    even `java.util.HashSet`, and places considerably less load on the garbage collector. Like
    `java.util.LinkedHashSet`, it offers insertion-order iteration, with identical behavior.
    
    This class should not be assumed to be universally superior to `java.util.LinkedHashSet`. Generally speaking, this class reduces object allocation and memory
    consumption at the price of moderately increased constant factors of CPU. Only use this class
    when there is a specific reason to prioritize memory over CPU.

    Author(s)
    - Louis Wasserman
    """

    @staticmethod
    def create() -> "CompactLinkedHashSet"["E"]:
        """
        Creates an empty `CompactLinkedHashSet` instance.
        """
        ...


    @staticmethod
    def create(collection: Iterable["E"]) -> "CompactLinkedHashSet"["E"]:
        """
        Creates a *mutable* `CompactLinkedHashSet` instance containing the elements of the
        given collection in the order returned by the collection's iterator.

        Arguments
        - collection: the elements that the set should contain

        Returns
        - a new `CompactLinkedHashSet` containing those elements (minus duplicates)
        """
        ...


    @staticmethod
    def create(*elements: Tuple["E", ...]) -> "CompactLinkedHashSet"["E"]:
        """
        Creates a `CompactLinkedHashSet` instance containing the given elements in unspecified
        order.

        Arguments
        - elements: the elements that the set should contain

        Returns
        - a new `CompactLinkedHashSet` containing those elements (minus duplicates)
        """
        ...


    @staticmethod
    def createWithExpectedSize(expectedSize: int) -> "CompactLinkedHashSet"["E"]:
        """
        Creates a `CompactLinkedHashSet` instance, with a high enough "initial capacity" that it
        *should* hold `expectedSize` elements without rebuilding internal data structures.

        Arguments
        - expectedSize: the number of elements you expect to add to the returned set

        Returns
        - a new, empty `CompactLinkedHashSet` with enough capacity to hold `expectedSize` elements without resizing

        Raises
        - IllegalArgumentException: if `expectedSize` is negative
        """
        ...


    def toArray(self) -> list["Object"]:
        ...


    def toArray(self, a: list["T"]) -> list["T"]:
        ...


    def spliterator(self) -> "Spliterator"["E"]:
        ...


    def clear(self) -> None:
        ...



"""
Python module generated from Java source file org.bukkit.scheduler.BukkitTask

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.plugin import Plugin
from org.bukkit.scheduler import *
from typing import Any, Callable, Iterable, Tuple


class BukkitTask:
    """
    Represents a task being executed by the scheduler
    """

    def getTaskId(self) -> int:
        """
        Returns the taskId for the task.

        Returns
        - Task id number
        """
        ...


    def getOwner(self) -> "Plugin":
        """
        Returns the Plugin that owns this task.

        Returns
        - The Plugin that owns the task
        """
        ...


    def isSync(self) -> bool:
        """
        Returns True if the Task is a sync task.

        Returns
        - True if the task is run by main thread
        """
        ...


    def isCancelled(self) -> bool:
        """
        Returns True if this task has been cancelled.

        Returns
        - True if the task has been cancelled
        """
        ...


    def cancel(self) -> None:
        """
        Will attempt to cancel this task.
        """
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.events.CollectionEndEvent

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.yaml.snakeyaml.error import Mark
from org.yaml.snakeyaml.events import *
from typing import Any, Callable, Iterable, Tuple


class CollectionEndEvent(Event):
    """
    Base class for the end events of the collection nodes.
    """

    def __init__(self, startMark: "Mark", endMark: "Mark"):
        """
        Create

        Arguments
        - startMark: - start
        - endMark: - end
        """
        ...



"""
Python module generated from Java source file com.google.common.util.concurrent.ForwardingFluentFuture

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.util.concurrent import *
from java.util.concurrent import ExecutionException
from java.util.concurrent import Executor
from java.util.concurrent import TimeUnit
from java.util.concurrent import TimeoutException
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class ForwardingFluentFuture(FluentFuture):
    """
    FluentFuture that forwards all calls to a delegate.
    
    <h3>Extension</h3>
    
    If you want a class like `FluentFuture` but with extra methods, we recommend declaring your
    own subclass of ListenableFuture, complete with a method like .from to adapt an
    existing `ListenableFuture`, implemented atop a ForwardingListenableFuture that
    forwards to that future and adds the desired methods.
    """

    def addListener(self, listener: "Runnable", executor: "Executor") -> None:
        ...


    def cancel(self, mayInterruptIfRunning: bool) -> bool:
        ...


    def isCancelled(self) -> bool:
        ...


    def isDone(self) -> bool:
        ...


    def get(self) -> "V":
        ...


    def get(self, timeout: int, unit: "TimeUnit") -> "V":
        ...


    def toString(self) -> str:
        ...



"""
Python module generated from Java source file java.io.FilenameFilter

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import *
from typing import Any, Callable, Iterable, Tuple


class FilenameFilter:
    """
    Instances of classes that implement this interface are used to
    filter filenames. These instances are used to filter directory
    listings in the `list` method of class
    `File`, and by the Abstract Window Toolkit's file
    dialog component.

    Author(s)
    - Jonathan Payne

    See
    - java.io.File.list(java.io.FilenameFilter)

    Since
    - 1.0
    """

    def accept(self, dir: "File", name: str) -> bool:
        """
        Tests if a specified file should be included in a file list.

        Arguments
        - dir: the directory in which the file was found.
        - name: the name of the file.

        Returns
        - `True` if and only if the name should be
        included in the file list; `False` otherwise.
        """
        ...



"""
Python module generated from Java source file org.bukkit.entity.EnderDragon

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import World
from org.bukkit.boss import DragonBattle
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class EnderDragon(ComplexLivingEntity, Boss, Mob, Enemy):
    """
    Represents an Ender Dragon
    """

    def getPhase(self) -> "Phase":
        """
        Gets the current phase that the dragon is performing.

        Returns
        - the current phase
        """
        ...


    def setPhase(self, phase: "Phase") -> None:
        """
        Sets the next phase for the dragon to perform.

        Arguments
        - phase: the next phase
        """
        ...


    def getDragonBattle(self) -> "DragonBattle":
        """
        Get the DragonBattle associated with this EnderDragon.
        
        This will return null for the following reasons:
        
            - The EnderDragon is not in the End dimension
            - The EnderDragon was summoned by command/API

        Returns
        - the dragon battle

        See
        - World.getEnderDragonBattle()
        """
        ...


    def getDeathAnimationTicks(self) -> int:
        """
        Get the current time in ticks relative to the start of this dragon's
        death animation.
        
        If this dragon is alive, 0 will be returned. This value will never exceed
        200 (the length of the animation).

        Returns
        - this dragon's death animation ticks
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.entity.EntityExplodeEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import ExplosionResult
from org.bukkit import Location
from org.bukkit.block import Block
from org.bukkit.entity import Entity
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.entity import *
from typing import Any, Callable, Iterable, Tuple


class EntityExplodeEvent(EntityEvent, Cancellable):
    """
    Called when an entity explodes
    """

    def __init__(self, what: "Entity", location: "Location", blocks: list["Block"], yield: float, result: "ExplosionResult"):
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getExplosionResult(self) -> "ExplosionResult":
        """
        Returns the result of the explosion if it is not cancelled.

        Returns
        - the result of the explosion
        """
        ...


    def blockList(self) -> list["Block"]:
        """
        Returns the list of blocks that would have been removed or were removed
        from the explosion event.

        Returns
        - All blown-up blocks
        """
        ...


    def getLocation(self) -> "Location":
        """
        Returns the location where the explosion happened.
        
        It is not possible to get this value from the Entity as the Entity no
        longer exists in the world.

        Returns
        - The location of the explosion
        """
        ...


    def getYield(self) -> float:
        """
        Returns the percentage of blocks to drop from this explosion

        Returns
        - The yield.
        """
        ...


    def setYield(self, yield: float) -> None:
        """
        Sets the percentage of blocks to drop from this explosion

        Arguments
        - yield: The new yield percentage
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.block.data.Rail

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.block.data import *
from typing import Any, Callable, Iterable, Tuple


class Rail(Waterlogged):
    """
    'shape' represents the current layout of a minecart rail.
    
    Some types of rail may not be able to be laid out in all shapes, use
    .getShapes() to get those applicable to this block.
    """

    def getShape(self) -> "Shape":
        """
        Gets the value of the 'shape' property.

        Returns
        - the 'shape' value
        """
        ...


    def setShape(self, shape: "Shape") -> None:
        """
        Sets the value of the 'shape' property.

        Arguments
        - shape: the new 'shape' value
        """
        ...


    def getShapes(self) -> set["Shape"]:
        """
        Gets the shapes which are applicable to this block.

        Returns
        - the allowed 'shape' values
        """
        ...


    class Shape(Enum):
        """
        The different types of shapes a rail block can occupy.
        """

        NORTH_SOUTH = 0
        """
        The rail runs flat along the north/south (Z) axis.
        """
        EAST_WEST = 1
        """
        The rail runs flat along the east/west (X) axis.
        """
        ASCENDING_EAST = 2
        """
        The rail ascends in the east (positive X) direction.
        """
        ASCENDING_WEST = 3
        """
        The rail ascends in the west (negative X) direction.
        """
        ASCENDING_NORTH = 4
        """
        The rail ascends in the north (negative Z) direction.
        """
        ASCENDING_SOUTH = 5
        """
        The rail ascends in the south (positive Z) direction.
        """
        SOUTH_EAST = 6
        """
        The rail forms a curve connecting the south and east faces of the
        block.
        """
        SOUTH_WEST = 7
        """
        The rail forms a curve connecting the south and west faces of the
        block.
        """
        NORTH_WEST = 8
        """
        The rail forms a curve connecting the north and west faces of the
        block.
        """
        NORTH_EAST = 9
        """
        The rail forms a curve connecting the north and east faces of the
        block.
        """



"""
Python module generated from Java source file com.google.gson.internal.ReflectionAccessFilterHelper

Java source file obtained from artifact gson version 2.11.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import ReflectionAccessFilter
from com.google.gson.ReflectionAccessFilter import FilterResult
from com.google.gson.internal import *
from java.lang.reflect import AccessibleObject
from java.lang.reflect import Method
from typing import Any, Callable, Iterable, Tuple


class ReflectionAccessFilterHelper:
    """
    Internal helper class for ReflectionAccessFilter.
    """

    @staticmethod
    def isJavaType(c: type[Any]) -> bool:
        ...


    @staticmethod
    def isAndroidType(c: type[Any]) -> bool:
        ...


    @staticmethod
    def isAnyPlatformType(c: type[Any]) -> bool:
        ...


    @staticmethod
    def getFilterResult(reflectionFilters: list["ReflectionAccessFilter"], c: type[Any]) -> "FilterResult":
        """
        Gets the result of applying all filters until the first one returns a result other than FilterResult.INDECISIVE, or FilterResult.ALLOW if the list of filters is empty or all
        returned `INDECISIVE`.
        """
        ...


    @staticmethod
    def canAccess(accessibleObject: "AccessibleObject", object: "Object") -> bool:
        """
        See AccessibleObject.canAccess(Object) (Java >= 9)
        """
        ...
